' ProMPT.bas
' ProMPT API for the melabs PicBasic Pro Compiler
'
' Version 2.44, 07/01/03
'
' To use, set PARAM1 and PARAM2 as necessary,
'  Gosub to API subroutine, any result is
'  returned in PRESULT.
'
' Example:
'	PARAM1 = 0
'	Gosub ProMPT_Init
'
' No BASIC code can appear until after the Asm section below

Define	OSC	20		' Requires 20MHz oscillator
Define	INTHAND	PROMPT_ISR	' Set up ProMPT interrupt vector

PARAM1	Var	Byte Ext	' Parameter 1 passed to ProMPT
PARAM2	Var	Byte Ext	' Parameter 2 passed to ProMPT

PRESULT	Var	Byte BankA	' Result returned from ProMPT


Asm
	ifdef BANK5_START
; Following lines are for 18Fx539
PARAM1:		equ	05c0h	; Parameter 1 passed to ProMPT
PARAM2:		equ	05c1h	; Parameter 2 passed to ProMPT
PROMPT:		equ	6000h	; ProMPT entry vector
PROMPT_ISR:	equ	6004h	; ProMPT interrupt vector
	else
; Following lines are for 18Fx439
PARAM1:		equ	02c0h	; Parameter 1 passed to ProMPT
PARAM2:		equ	02c1h	; Parameter 2 passed to ProMPT
PROMPT:		equ	3000h	; ProMPT entry vector
PROMPT_ISR:	equ	3004h	; ProMPT interrupt vector
	endif

; Jump table locations
ClearTick:		equ	1
DisableBoostMode:	equ	2
EnableBoostMode:	equ	3
GetFrequency:		equ	4
GetModulation:		equ	5
PInit:			equ	6
SetAccelRate:		equ	7
SetBoostEndModulation:	equ	8
SetBoostFrequency:	equ	9
SetBoostStartModulation: equ	10
SetBoostTime:		equ	11
SetDecelRate:		equ	12
SetFrequency:		equ	13
SetLineVoltage:		equ	14
SetMotorVoltage:	equ	15
SetPWMfrequency:	equ	16
SetVFCurve:		equ	17
GetVFCurve:		equ	18
Start:			equ	19
Stop:			equ	20
Tick:			equ	21
SetParameter:		equ	22
GetParameter:		equ	23
GetAccelRate:		equ	24
GetBoostEndModulation:	equ	25
GetBoostFrequency:	equ	26
GetBoostStartModulation: equ	27
GetBoostTime:		equ	28
GetDecelRate:		equ	29

Endasm

	Goto	ProMPTEnd	' Skip over ProMPT routines


' API Gosub entries
ProMPT_ClearTick:	
@	movlw	ClearTick
@	call	PROMPT
@	movlb	0
	Return
	
ProMPT_DisableBoostMode:
@	movlw	DisableBoostMode
@	call	PROMPT
@	movlb	0
	Return
	
ProMPT_EnableBoostMode:
@	movlw	EnableBoostMode
@	call	PROMPT
@	movlb	0
	Return
	
ProMPT_GetFrequency:
@	movlw	GetFrequency
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return

ProMPT_GetModulation:
@	movlw	GetModulation
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return

ProMPT_Init:			' Has a single parameter in PARAM1
@	movlw	PInit
@	call	PROMPT
@	movlb	0
	Return

ProMPT_SetAccelRate:		' Has a single parameter in PARAM1
@	movlw	SetAccelRate
@	call	PROMPT
@	movlb	0
	Return

ProMPT_SetBoostEndModulation:	' Has a single parameter in PARAM1
@	movlw	SetBoostEndModulation
@	call	PROMPT
@	movlb	0
	Return
	
ProMPT_SetBoostFrequency:	' Has a single parameter in PARAM1
@	movlw	SetBoostFrequency
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return
	
ProMPT_SetBoostStartModulation:	' Has a single parameter in PARAM1
@	movlw	SetBoostStartModulation
@	call	PROMPT
@	movlb	0
	Return

ProMPT_SetBoostTime:		' Has a single parameter in PARAM1
@	movlw	SetBoostTime
@	call	PROMPT
@	movlb	0
	Return

ProMPT_SetDecelRate:		' Has a single parameter in PARAM1
@	movlw	SetDecelRate
@	call	PROMPT
@	movlb	0
	Return
	
ProMPT_SetFrequency:		' Has a single parameter in PARAM1
@	movlw	SetFrequency
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return

ProMPT_SetLineVoltage:		' Has a single parameter in PARAM1
@	movlw	SetLineVoltage
@	call	PROMPT
@	movlb	0
	Return

ProMPT_SetMotorVoltage:		' Has a single parameter in PARAM1
@	movlw	SetMotorVoltage
@	call	PROMPT
@	movlb	0
	Return

ProMPT_SetPWMfrequency:		' Has a single parameter in PARAM1
@	movlw	SetPWMfrequency
@	call	PROMPT
@	movlb	0
	Return

ProMPT_SetVFCurve:		' Has a two parameters in PARAM1 (value) and PARAM2 (point)
@	movlw	SetVFCurve
@	call	PROMPT
@	movlb	0
	Return

ProMPT_GetVFCurve:		' Has a single parameter in PARAM1
@	movlw	GetVFCurve
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return
	
ProMPT_Start:
@	movlw	Start
@	call	PROMPT
@	movlb	0
	Return

ProMPT_Stop:
@	movlw	Stop
@	call	PROMPT
@	movlb	0
	Return

ProMPT_Tick:
@	movlw	Tick
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return

ProMPT_SetParameter:		' Has a two parameters in PARAM1 (value) and PARAM2 (address)
@	movlw	SetParameter
@	call	PROMPT
@	movlb	0
	Return

ProMPT_GetParameter:		' Has a single parameter in PARAM1
@	movlw	GetParameter
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return

ProMPT_GetAccelRate:
@	movlw	GetAccelRate
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return

ProMPT_GetBoostEndModulation:
@	movlw	GetBoostEndModulation
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return
	
ProMPT_GetBoostFrequency:
@	movlw	GetBoostFrequency
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return

ProMPT_GetBoostStartModulation:
@	movlw	GetBoostStartModulation
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return

ProMPT_GetBoostTime:
@	movlw	GetBoostTime
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return				

ProMPT_GetDecelRate:
@	movlw	GetDecelRate
@	call	PROMPT
@	movlb	0
@	movwf	_PRESULT, 0
	Return				

ProMPTEnd:

